classdef FrameType < uint32
  % FrameType
  %   The different frame types that are supported
  %

  enumeration
    RAW_COMMON (0) % The 16bits coming off the OPT8241 image sensor
    COMMON (1) % Common (A + B) image, 4 or 12 bits depending on the sensor
    RAW (2) % Raw (A - B) image 12 bits signed data
    REAL (3) % The real image
    IMAGINARY (4) % The imaginary image
    PHASE (5) % The phase image
    AMPLITUDE (6) % The amplitude image
    RADIAL (7) % The radial distance image
    INTENSITY (8) % The intensity image
    X (9) % The x image of the point cloud
    Y (10) % The y image of the point cloud
    Z (11) % The z image of the point cloud
    XYZ (12) % A complete pointcloud image: float x, float y, float z, float padding
    XYZ_AMP (13) % A complete pointcloud image with amplitude: float x, float y, float z, float amplitude
    XYZ_BGR (14) % A complete pointcloud image with bgr: float x, float y, float z, uint8 b, uint8 g, uint8 r, uint8 padding
    XYZ_BGR_I (15) % A complete pointcloud image with bgr and intensity: float x, float y, float z, uint8 b, uint8 g, uint8 r, uint8 intensity
    BGR (18) % A color image, encode bgr
    YUV (19) % A color image encoded in YUV422
    RAW_AB (20) % A raw image containing both the A and B tap
    MJPEG (21) % a color image encoded in mjpeg
    BGR_PROJECTED (22) % A color image projected to the XYZ locations of the depth sensor
    COMPRESSED_DOT (23) % The averaged value for each dot. In the XYZAmp format.
    RAW_AB_SUPER (24) % The raw information coming out of the vd55h1 sensor.  This is not very useful by itself, but when stored in a CSF file, it reproduces the actual pipeline correctly.  This also allows to retrieve data from camera without any processing.
    REFLECTIVITY (25) % The reflectivity of an object in the IR domain.  This is comparable to a black and white image.  Do note that due to the angle of incidence and multi path the reflectivity can still change over distance When selecting both intensity and reflectivity as outputs, radial and intensity are streamed from the camera and the reflectivity will be slightly quantized.
  end
end
